package
Version:
v0.0.0-...-2d0e9f7
Opens a new window with list of versions in this module.
Published: May 26, 2022
License: Apache-2.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Bool interface {
~bool
}
type String interface {
~string
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.