Documentation
¶
Index ¶
- Constants
- func Contains(str, substr string, ignoreCase bool) bool
- func CutByMax(str string, max int) string
- func EmptyToDefault(str, defaultStr string) string
- func HasEmpty(strs ...string) bool
- func HasSpace(strs ...string) bool
- func IsAllEmpty(strs ...string) bool
- func IsAllNotEmpty(strs ...string) bool
- func IsAllNotSpace(strs ...string) bool
- func IsAllSpace(strs ...string) bool
- func IsEmpty(str string) bool
- func IsEmptyOrUnderfined(str string) bool
- func IsEndWith(str, suffix string, ignoreCase bool) bool
- func IsEndWithAny(str string, ignoreCase bool, suffixs ...string) bool
- func IsNotEmpty(str string) bool
- func IsNotSpace(str string) bool
- func IsNullOrUnderfined(str string) bool
- func IsSpace(str string) bool
- func IsSpaceOrUnderfined(str string) bool
- func IsStartWith(str, prefix string, ignoreCase bool) bool
- func IsStartWithAny(str string, ignoreCase bool, prefixes ...string) bool
- func SpaceToDefault(str, defaultStr string) string
- func ToSymbolCase(str string, symbol byte) string
- func ToUnderLineCase(str string) string
- func TrimSpace(str string) string
- func TrimSpaceLeft(str string) string
- func TrimSpaceRight(str string) string
Constants ¶
const ( NULL = "null" Undefind = "undefined" MoreInfoTarget = "..." )
Variables ¶
This section is empty.
Functions ¶
func EmptyToDefault ¶
EmptyToDefault Check if a string is empty ,if it's empty ,set a default value.
func HasSpace ¶
HasSpace Check if has Space string in the array of string. is equivalent to : IsSpace(...) || IsSpace(...) || ...
func IsAllNotEmpty ¶
IsAllNotEmpty Check if all of strs is Empty.
func IsAllNotSpace ¶
IsAllNotSpace Check if all of strs is Space.
func IsAllSpace ¶
IsAllSpace Check if all string is Space IsAllSpace is equivalent to : IsSpace(...) && IsSpace(...) && ...
func IsEmpty ¶
IsEmpty Check if a string is empty. Empty means 1. "" 2. len(str) == 0 E.g: 1. IsEmpty("") == true 2. IsEmpty(" ") == false 3. IsEmpty(" \n \t \r") = false
IsEmpty can't check blank string.Check blank string should use IsBlank
func IsEmptyOrUnderfined ¶
func IsNullOrUnderfined ¶
isNullOrUnderfined Check if str is null or undefined
func IsSpaceOrUnderfined ¶
func IsStartWith ¶
IsStartWith Checks if the str starts with a prefix ignoreCase ,Indicates whether case is ignored
func SpaceToDefault ¶
SpaceToDefault Check if a string is Space ,if it's Space ,set a default value.
func ToSymbolCase ¶
func ToUnderLineCase ¶
func TrimSpaceLeft ¶
TrimSpaceLeft Removes space char at the beginning of the string
func TrimSpaceRight ¶
TrimSpaceRight Removes space char at the end of the string
Types ¶
This section is empty.